@@ -3,7 +3,10 @@ use reqwest::blocking::Response;
 use serde_json::Value;
 use termion::color;
 
-pub fn write_response_headers(response: &Response) -> Result<()> {
+pub fn write_response_headers(response: &Response, verbose: usize) -> Result<()> {
+    if verbose < 1 {
+        return Ok(());
+    }
     let colored = atty::is(atty::Stream::Stderr);
 
     if colored {
@@ -29,7 +32,7 @@ pub fn write_json(response: Value) -> Result<Value> {
     Ok(response)
 }
 
-pub fn write_response_full(response: Response) -> Result<Value> {
-    write_response_headers(&response)?;
+pub fn write_response_full(response: Response, verbose: usize) -> Result<Value> {
+    write_response_headers(&response, verbose)?;
     write_json(response.json()?)
 }
