@@ -31,20 +31,22 @@ fn main() -> Result<()> {
         Command::Add {
             content_type,
             file,
+            primary,
             r#async,
         } => {
             meili
                 .r#async(r#async)
-                .index_documents(file, content_type, false)?;
+                .index_documents(file, primary, content_type, false)?;
         }
         Command::Update {
             content_type,
             file,
+            primary,
             r#async,
         } => {
             meili
                 .r#async(r#async)
-                .index_documents(file, content_type, true)?;
+                .index_documents(file, primary, content_type, true)?;
         }
         Command::Delete {
             document_ids,
@@ -69,9 +71,19 @@ fn main() -> Result<()> {
         Command::Index { command } => match command {
             IndexesCommand::All => meili.get_all_indexes()?,
             IndexesCommand::Get { index } => meili.get_index(index)?,
-            IndexesCommand::Create { index, primary } => meili.create_index(index, primary)?,
-            IndexesCommand::Update { index, primary } => meili.update_index(index, primary)?,
-            IndexesCommand::Delete { index } => meili.delete_index(index)?,
+            IndexesCommand::Create {
+                index,
+                primary,
+                r#async,
+            } => meili.r#async(r#async).create_index(index, primary)?,
+            IndexesCommand::Update {
+                index,
+                primary,
+                r#async,
+            } => meili.r#async(r#async).update_index(index, primary)?,
+            IndexesCommand::Delete { index, r#async } => {
+                meili.r#async(r#async).delete_index(index)?
+            }
         },
         Command::Dump {
             r#async,
@@ -85,7 +97,17 @@ fn main() -> Result<()> {
         Command::Version => meili.version()?,
         Command::Stats => meili.stats()?,
         Command::Status { update_id, watch } => meili.r#async(!watch).status(update_id)?,
-        Command::Task { task_id, watch } => meili.r#async(!watch).task(task_id)?,
+        Command::Task {
+            task_id,
+            watch,
+            all: true,
+        } => meili.r#async(!watch).global_task(task_id)?,
+        Command::Task {
+            task_id,
+            watch,
+            all: false,
+        } => meili.r#async(!watch).task_by_index(task_id)?,
+        Command::Key => meili.keys()?,
     }
 
     Ok(())
