@@ -12,7 +12,7 @@ use anyhow::Result;
 use indicatif::ProgressBar;
 use reqwest::{
     blocking::{Client, RequestBuilder, Response},
-    header::{AUTHORIZATION, USER_AGENT},
+    header::{AUTHORIZATION, CONTENT_TYPE, USER_AGENT},
     StatusCode,
 };
 use serde_json::{json, Map, Value};
@@ -102,6 +102,7 @@ impl Meilisearch {
     pub fn index_documents(
         &self,
         filepath: Option<PathBuf>,
+        primary_key: Option<String>,
         content_type: String,
         reindex: bool,
     ) -> Result<()> {
@@ -110,24 +111,24 @@ impl Meilisearch {
             false => self.post(url),
             true => self.put(url),
         };
+        let client = client.header(CONTENT_TYPE, content_type);
+        let client = if let Some(primary_key) = primary_key {
+            client.query(&[("primaryKey", primary_key)])
+        } else {
+            client
+        };
 
         let response = match filepath {
             Some(filepath) => {
                 let file = File::open(filepath)?;
-                client
-                    .header("Content-Type", content_type)
-                    .body(file)
-                    .send()?
+                client.body(file).send()?
             }
             None => {
                 // TODO: is this the only way to do it?
                 let mut buffer = Vec::new();
                 stdin().read_to_end(&mut buffer);
 
-                client
-                    .header("Content-Type", content_type)
-                    .body(buffer)
-                    .send()?
+                client.body(buffer).send()?
             }
         };
         self.handle_response(response)
@@ -242,11 +243,9 @@ impl Meilisearch {
     pub fn update_index(&self, index: Option<String>, primary_key: Option<String>) -> Result<()> {
         let index = index.unwrap_or(self.index.to_string());
         let mut body = json!({});
-        dbg!(&primary_key);
         if let Some(primary_key) = primary_key {
             body["primaryKey"] = json!(primary_key);
         }
-        dbg!(&body);
         let response = self
             .put(format!("{}/indexes/{}", self.addr, index))
             .json(&body)
@@ -274,7 +273,7 @@ impl Meilisearch {
         self.handle_response(response)
     }
 
-    pub fn task(&self, tid: Option<TaskId>) -> Result<()> {
+    pub fn task_by_index(&self, tid: Option<TaskId>) -> Result<()> {
         let response = self
             .get(format!(
                 "{}/indexes/{}/tasks/{}",
@@ -286,6 +285,17 @@ impl Meilisearch {
         self.handle_response(response)
     }
 
+    pub fn global_task(&self, tid: Option<TaskId>) -> Result<()> {
+        let response = self
+            .get(format!(
+                "{}/tasks/{}",
+                self.addr,
+                tid.map_or("".to_string(), |uid| uid.to_string())
+            ))
+            .send()?;
+        self.handle_response(response)
+    }
+
     pub fn create_dump(&self) -> Result<()> {
         let response = self.post(format!("{}/dumps", self.addr)).send()?;
         self.handle_response(response)
@@ -313,6 +323,11 @@ impl Meilisearch {
         self.handle_response(response)
     }
 
+    pub fn keys(&self) -> Result<()> {
+        let response = self.get(format!("{}/keys", self.addr)).send()?;
+        self.handle_response(response)
+    }
+
     pub fn handle_response(&self, response: Response) -> Result<()> {
         if response.status() == StatusCode::NO_CONTENT {
             return write_response_headers(&response, self.verbose);
